==> rCGH_1.0.2.tar.gz: rCGH/man/rCGH-Agilent-class.Rd <==
\name{rCGH-Agilent-class}
\Rdversion{1.1}
\docType{class}
\alias{rCGH-Agilent-class}

\title{Class \code{"rCGH-Agilent"}}

\description{
An instance of class \code{"rCGH-Agilent"}, which inherits from
the superclass \code{"\linkS4class{rCGH}"}.\cr
Slots described below are used to store sample information, analysis
parameters, and segmentation results. All are accessible through specific
\code{"\link{Accessors}"} functions.
}

\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("rCGH-Agilent", ...)}.
}

\section{Slots}{
    \describe{
        \item{\code{info}:}{
        Object of class \code{"character"}: where sample information can be 
        stored. See \code{\link{getInfo}} and \code{\link{setInfo}}.
        }
        \item{\code{cnSet}:}{
        Object of class \code{"data.frame"}: the full data set.
        See \code{\link{getCNset}}.
        }
        \item{\code{param}:}{
        Object of class \code{"list"}: the analysis parameters stored for
        traceability. \code{\link{getParam}}.
        }
        \item{\code{segTable}:}{
        Object of class \code{"data.frame"}: the segmentation table.
        \code{\link{getSegTable}}.
        }
    }
}

\section{Extends}{
Class \code{"\linkS4class{rCGH}"}, directly.
}

\section{Methods}{
No methods defined with class "rCGH-Agilent" in the signature.
}

\author{
Frederic Commo
}

\seealso{
\code{"\linkS4class{rCGH}"}, \code{"\linkS4class{rCGH-cytoScan}"}, 
\code{"\linkS4class{rCGH-SNP6}"}
}

\examples{
showClass("rCGH-Agilent")
}

\keyword{classes}

==> rCGH_1.14.0.tar.gz: rCGH/man/rCGH-Agilent-class.Rd <==
\name{rCGH-Agilent-class}
\Rdversion{1.1}
\docType{class}
\alias{rCGH-Agilent-class}

\title{Class \code{"rCGH-Agilent"}}

\description{
An instance of class \code{"rCGH-Agilent"}, which inherits from
the superclass \code{"\linkS4class{rCGH}"}.\cr
Slots described below are used to store sample information, analysis
parameters, and segmentation results. All are accessible through specific
\code{"\link{Accessors}"} functions.
}

\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("rCGH-Agilent", ...)}.
}

\section{Slots}{
    \describe{
        \item{\code{info}:}{
        Object of class \code{"character"}: where sample information can be 
        stored. See \code{\link{getInfo}} and \code{\link{setInfo}}.
        }
        \item{\code{cnSet}:}{
        Object of class \code{"data.frame"}: the full data set.
        See \code{\link{getCNset}}.
        }
        \item{\code{param}:}{
        Object of class \code{"list"}: the analysis parameters stored for
        traceability. \code{\link{getParam}}.
        }
        \item{\code{segTable}:}{
        Object of class \code{"data.frame"}: the segmentation table.
        \code{\link{getSegTable}}.
        }
    }
}

\section{Extends}{
Class \code{"\linkS4class{rCGH}"}, directly.
}

\section{Methods}{
No methods defined with class "rCGH-Agilent" in the signature.
}

\author{
Frederic Commo
}

\seealso{
\code{"\linkS4class{rCGH}"}, \code{"\linkS4class{rCGH-cytoScan}"}, 
\code{"\linkS4class{rCGH-SNP6}"}, \code{"\linkS4class{rCGH-generic}"}
}

\examples{
showClass("rCGH-Agilent")
}

\keyword{classes}
